==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/pt.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: pt.php,v 1.11 2005/12/07 15:02:11 bigmichi1 Exp $

$text['title']          = 'Informaes do Sistema';

$text['vitals']         = 'Informaes Vitais';
$text['hostname']       = 'Hostname Cannico';
$text['ip']             = 'IP';
$text['kversion']       = 'Verso do Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Utilizadores Ligados';
$text['loadavg']        = 'Carga Mdia';

$text['hardware']       = 'Informaes do Hardware';
$text['numcpu']         = 'Processadores';
$text['cpumodel']       = 'Modelo';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Tamanho da Cache';
$text['bogomips']       = 'Bogomips do Sistema';

$text['pci']            = 'Hardware PCI';
$text['ide']            = 'Hardware IDE';
$text['scsi']           = 'Hardware SCSI';
$text['usb']            = 'Hardware USB';

$text['netusage']       = 'Utilizao da Rede';
$text['device']         = 'Dispositivo';
$text['received']       = 'Recebidos';
$text['sent']           = 'Enviados';
$text['errors']         = 'Erro/Rejeitados';

$text['connections']    = 'Ligaes Estabelecidas';

$text['memusage']       = 'Utilizao da Memria';
$text['phymem']         = 'Memria Fsica';
$text['swap']           = 'Swap';

$text['fs']             = 'Sistema de Ficheiros (Mounted)';
$text['mount']          = 'Mount';
$text['partition']      = 'Parties';

$text['percent']        = 'Capacidade em Percentagem';
$text['type']           = 'Tipo';
$text['free']           = 'Livre';
$text['used']           = 'Utilizada';
$text['size']           = 'Tamanho';
$text['totals']         = 'Totais';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'indisponvel';

$text['capacity']       = 'Capacidade'; 

$text['template']       = 'Template';
$text['language']       = 'Idioma';
$text['submit']         = 'Enviar';
$text['created']        = 'Produzido por';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dias';
$text['hours']          = 'horas';
$text['minutes']        = 'minutos';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/pt.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: pt.php,v 1.13 2006/06/05 11:48:16 bigmichi1 Exp $

$text['title']          = 'Informaes do Sistema';

$text['vitals']         = 'Informaes Vitais';
$text['hostname']       = 'Hostname Cannico';
$text['ip']             = 'IP';
$text['kversion']       = 'Verso do Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Utilizadores Ligados';
$text['loadavg']        = 'Carga Mdia';

$text['hardware']       = 'Informaes do Hardware';
$text['numcpu']         = 'Processadores';
$text['cpumodel']       = 'Modelo';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Tamanho da Cache';
$text['bogomips']       = 'Bogomips do Sistema';

$text['pci']            = 'Hardware PCI';
$text['ide']            = 'Hardware IDE';
$text['scsi']           = 'Hardware SCSI';
$text['usb']            = 'Hardware USB';

$text['netusage']       = 'Utilizao da Rede';
$text['device']         = 'Dispositivo';
$text['received']       = 'Recebidos';
$text['sent']           = 'Enviados';
$text['errors']         = 'Erro/Rejeitados';

$text['connections']    = 'Ligaes Estabelecidas';

$text['memusage']       = 'Utilizao da Memria';
$text['phymem']         = 'Memria Fsica';
$text['swap']           = 'Swap';

$text['fs']             = 'Sistema de Ficheiros (Mounted)';
$text['mount']          = 'Mount';
$text['partition']      = 'Parties';

$text['percent']        = 'Capacidade em Percentagem';
$text['type']           = 'Tipo';
$text['free']           = 'Livre';
$text['used']           = 'Utilizada';
$text['size']           = 'Tamanho';
$text['totals']         = 'Totais';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'indisponvel';

$text['capacity']       = 'Capacidade'; 

$text['template']       = 'Template';
$text['language']       = 'Idioma';
$text['submit']         = 'Enviar';
$text['created']        = 'Produzido por';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dias';
$text['hours']          = 'horas';
$text['minutes']        = 'minutos';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
